@@ -1,34 +1,34 @@
 import requests
 
 
-def deploy(mc_endpoint, token):
+def deploy(mc_endpoint, token, verify=True):
     endpoint = mc_endpoint + "/user/deploy"
     headers = {"Authorization": f"Bearer {token}"}
 
-    return requests.get(endpoint, headers=headers)
+    return requests.get(endpoint, headers=headers, verify=verify)
 
 
-def get_status(mc_endpoint, token):
+def get_status(mc_endpoint, token, verify=True):
     endpoint = mc_endpoint + "/user/get_status"
     headers = {"Authorization": f"Bearer {token}"}
 
-    return requests.get(endpoint, headers=headers)
+    return requests.get(endpoint, headers=headers, verify=verify)
 
 
-def info(mc_endpoint, token):
+def info(mc_endpoint, token, verify=True):
     endpoint = mc_endpoint + "/info"
     headers = {"Authorization": f"Bearer {token}"}
 
-    return requests.get(endpoint, headers=headers)
+    return requests.get(endpoint, headers=headers, verify=verify)
 
 
-def local_username(mc_endpoint, token):
+def local_username(mc_endpoint, token, verify=True):
     try:
-        resp = get_status(mc_endpoint, token)
+        resp = get_status(mc_endpoint, token, verify=verify)
         if resp.status_code == requests.codes.ok:
             output = resp.json()
             if output["state"] == "not_deployed":
-                resp = deploy(mc_endpoint, token)
+                resp = deploy(mc_endpoint, token, verify=verify)
                 if resp.status_code == requests.codes.ok:
                     return resp.json()["credentials"]["ssh_user"]
             else:
@@ -38,4 +38,4 @@ def local_username(mc_endpoint, token):
             resp.raise_for_status()
     except Exception as e:
         print(f"[motley_cue] {e}")
-    raise Exception("Failed to get ssh username")
\ No newline at end of file
+    raise Exception("Failed to get ssh username")
